@@ -136,7 +136,7 @@ get_xkb_desc_rec (GsdA11yKeyboardManager *manager)
                 desc->ctrls = NULL;
                 status = XkbGetControls (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), XkbAllControlsMask, desc);
         }
-        gdk_error_trap_pop ();
+        gdk_error_trap_pop_ignored ();
 
         g_return_val_if_fail (desc != NULL, NULL);
         g_return_val_if_fail (desc->ctrls != NULL, NULL);
@@ -334,7 +334,7 @@ set_server_from_gsettings (GsdA11yKeyboardManager *manager)
         XkbFreeKeyboard (desc, XkbAllComponentsMask, True);
 
         XSync (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), FALSE);
-        gdk_error_trap_pop ();
+        gdk_error_trap_pop_ignored ();
 
         gnome_settings_profile_end (NULL);
 }
@@ -784,7 +784,9 @@ set_gsettings_from_server (GsdA11yKeyboardManager *manager)
                 return;
         }
 
-        settings = manager->priv->settings;
+	/* Create a new one, so that only those settings
+	 * are delayed */
+        settings = g_settings_new (KEYBOARD_A11Y_SCHEMA);
         g_settings_delay (settings);
 
         /*
@@ -885,6 +887,7 @@ set_gsettings_from_server (GsdA11yKeyboardManager *manager)
         XkbFreeKeyboard (desc, XkbAllComponentsMask, True);
 
         g_settings_apply (settings);
+        g_object_unref (settings);
 }
 
 static GdkFilterReturn
@@ -984,6 +987,9 @@ gsd_a11y_keyboard_manager_start (GsdA11yKeyboardManager *manager,
 static void
 restore_server_xkb_config (GsdA11yKeyboardManager *manager)
 {
+        if (manager->priv->original_xkb_desc == NULL) {
+                return;
+        }
         gdk_error_trap_push ();
         XkbSetControls (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()),
                         XkbSlowKeysMask         |
@@ -1001,7 +1007,7 @@ restore_server_xkb_config (GsdA11yKeyboardManager *manager)
                          XkbAllComponentsMask, True);
 
         XSync (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), FALSE);
-        gdk_error_trap_pop ();
+        gdk_error_trap_pop_ignored ();
 
         manager->priv->original_xkb_desc = NULL;
 }
@@ -1018,11 +1024,15 @@ gsd_a11y_keyboard_manager_stop (GsdA11yKeyboardManager *manager)
                 p->device_manager = NULL;
         }
 
-        if (p->status_icon)
+        if (p->status_icon) {
                 gtk_status_icon_set_visible (p->status_icon, FALSE);
+                p->status_icon = NULL;
+        }
 
-        g_object_unref (p->settings);
-        p->settings = NULL;
+        if (p->settings != NULL) {
+                g_object_unref (p->settings);
+                p->settings = NULL;
+        }
 
         gdk_window_remove_filter (NULL,
                                   (GdkFilterFunc) cb_xkb_event_filter,
@@ -1032,11 +1042,15 @@ gsd_a11y_keyboard_manager_stop (GsdA11yKeyboardManager *manager)
          */
         restore_server_xkb_config (manager);
 
-        if (p->slowkeys_alert != NULL)
+        if (p->slowkeys_alert != NULL) {
                 gtk_widget_destroy (p->slowkeys_alert);
+                p->slowkeys_alert = NULL;
+        }
 
-        if (p->stickykeys_alert != NULL)
+        if (p->stickykeys_alert != NULL) {
                 gtk_widget_destroy (p->stickykeys_alert);
+                p->stickykeys_alert = NULL;
+        }
 
         p->slowkeys_shortcut_val = FALSE;
         p->stickykeys_shortcut_val = FALSE;
@@ -1159,6 +1173,7 @@ gsd_a11y_keyboard_manager_ensure_status_icon (GsdA11yKeyboardManager *manager)
         if (!manager->priv->status_icon) {
 
                 manager->priv->status_icon = gtk_status_icon_new_from_icon_name ("preferences-desktop-accessibility");
+                gtk_status_icon_set_name (manager->priv->status_icon, "a11y-keyboard");
                 g_signal_connect (manager->priv->status_icon,
                                   "activate",
                                   G_CALLBACK (on_status_icon_activate),
