@@ -211,6 +211,7 @@ static TranslationEntry translations [] = {
         { "org.gnome.desktop.interface", "cursor-size",            "Gtk/CursorThemeSize",     translate_int_int },
         { "org.gnome.desktop.interface", "show-input-method-menu", "Gtk/ShowInputMethodMenu", translate_bool_int },
         { "org.gnome.desktop.interface", "show-unicode-menu",      "Gtk/ShowUnicodeMenu",     translate_bool_int },
+        { "org.gnome.desktop.interface", "automatic-mnemonics",    "Gtk/AutoMnemonics",       translate_bool_int },
 
         { "org.gnome.desktop.sound", "theme-name",                 "Net/SoundThemeName",            translate_string_string },
         { "org.gnome.desktop.sound", "event-sounds",               "Net/EnableEventSounds" ,        translate_bool_int },
@@ -589,7 +590,7 @@ xsettings_callback (GSettings             *settings,
 
         process_value (manager, trans, value);
 
-        g_object_unref (value);
+        g_variant_unref (value);
 
         for (i = 0; manager->priv->managers [i]; i++) {
                 xsettings_manager_set_string (manager->priv->managers [i],
@@ -714,6 +715,7 @@ gnome_xsettings_manager_start (GnomeXSettingsManager *manager,
         manager->priv->gtk = gsd_xsettings_gtk_new ();
         g_signal_connect (G_OBJECT (manager->priv->gtk), "notify::gtk-modules",
                           G_CALLBACK (gtk_modules_callback), manager);
+        gtk_modules_callback (manager->priv->gtk, NULL, manager);
 
         /* Xft settings */
         update_xft_settings (manager);
